==> pydantic_errors_messages_translations-1.1.0.tar.gz: pydantic_errors_messages_translations-1.1.0/pydantic_errors_messages_translations/translations.py <==
from typing import Dict


pydantic_msg_template_translations: Dict[str: Dict] = {
    'pt_BR': {
        "field required": "Campo Obrigatório", 
        "extra fields not permitted": "Campos adicinais não são permitidos", 
        "none is not an allowed value": "Nulo não é um valor permitido", 
        "value is not none": "Valor não é nulo", 
        "value is not None": "Valor não é nulo", 
        "value could not be parsed to a boolean": "Valor não poderia ser convertido para um booleano",
        "byte type expected": "Tipo binário esperado era", 
        "value is not a valid dict": "Valor não é um dicionário válido", 
        "value is not a valid email address": "nao é um endereço de e-mail válido", 
        "invalid or missing URL scheme": "URL inválido ou faltando", 
        "URL scheme not permitted": "Formato de URL não permitido", 
        "userinfo required in URL but missing": "userinfo required in URL but missing", 
        "URL host invalid": "Dominio inválido", 
        "URL host invalid, top level domain required": "É necessário que a URL tenha um Top Level Domain", 
        "URL port invalid, port cannot exceed 65535": "URL porta inválida, porta não pode exceder 65535", 
        "URL invalid, extra characters found after valid URL: {}": "URL inválida, caracteres extras foram encontrados após a URL: {}", 
        "{} is not a valid Enum instance": "{} Não é uma instância válida de Enum", 
        "{} is not a valid IntEnum instance": "{} não é uma instância válida de IntEnum", 
        "value is not a valid integer": "Não é um número válido", 
        "value is not a valid float": "Não é um número válido", 
        "value is not a valid path": "Não um diretorio válido", 
        "file or directory at path '{}' does not exist":  "Arquivo ou diretório neste caminho '{}' não existe", 
        "path '{}' does not point to a file": "O caminho '{}' não aponta para um arquivo", 
        "path '{}' does not point to a directory": "O caminho '{}' não aponta para um diretório", 
        "ensure this value contains valid import path or valid callable: {}": "O valor não contém uma importação para um arquivo ou função válida: {}", 
        "value is not a valid sequence": "Valor não é uma sequência válida", 
        "value is not a valid list": "Valor não é uma lista válida", 
        "value is not a valid set": "Valor não é um conjunto válido", 
        "value is not a valid frozenset": "Valor não é um frozenset válido", 
        "value is not a valid tuple": "Valor não é uma tupla válida", 
        "wrong tuple length {}": "wrong tuple length {}", 
        "ensure this value has at least {} items": "Este campo precisa ter menos que {} itens", 
        "ensure this value has at most {} items": "Este campo precisa ter mais que {} items", 
        "the list has duplicated items": "Contém itens duplicados", 
        "ensure this value has at least {} characters": "Este campo precisa ter menos que {} caracteres", 
        "ensure this value has at most {} characters": "Este campo precisa ter mais que {} caracteres", 
        "str type expected": "O valor precisa ser um texto", 
        "string does not match regex '{}'": "string does not match regex '{}'", 
        "ensure this value is greater than {}": "O valor deve ser maior que {}", 
        "ensure this value is greater than or equal to {}": "ensure this value is greater than or equal to {}", 
        "ensure this value is less than {}": "ensure this value is less than {}", 
        "ensure this value is less than or equal to {}": "ensure this value is less than or equal to {}", 
        "ensure this value is a multiple of {}": "ensure this value is a multiple of {}", 
        "value is not a valid decimal": "Não é um número decimal válido", 
        "ensure that there are no more than {} digits in total": "Não deve ter menos que {} dígitos no total", 
        "ensure that there are no more than {} decimal places": "Não deve ter mais que {} casas decimais", 
        "ensure that there are no more than {} digits before the decimal point": "Deve ter mais que {} digitos antes do ponto", 
        "invalid datetime format": "Formato de data e hora inválido", 
        "invalid date format": "Formato de data inválido", 
        "date is not in the past": "A Data não pode ser menor que agora", 
        "date is not in the future": "A Data não pode ser maior que agora", 
        "invalid time format": "Formato de tempo inválido", 
        "invalid duration format": "iDUração de tempo inválida", 
        "value is not a valid hashable": "Não é um hash válido", 
        "value is not a valid uuid": "Não é um uuid válido", 
        "uuid version {} expected": "uuid version {} expected", 
        "instance of {} expected": "Uma instância de {} era esperada", 
        "a class is expected": "Uma classe era esperada", 
        "subclass of {} expected": "Uma subclasse de {} era esperada", 
        "Invalid JSON": "JSON inválido", 
        "JSON object must be str, bytes or bytearray": "O JSON enviado precisa ser texto, binário ou uma lista de arquivos binários", 
        "Invalid regular expression": "Expressão regular inválida", 
        "instance of {}, tuple or dict expected": "Uma instância de {}, tupla ou dicionário era esperada", 
        "{} is not callable": "{} não é uma função", 
        "value is not a valid IPv4 or IPv6 address": "Não é um endereço IPv4 or IPv6", 
        "value is not a valid IPv4 or IPv6 interface": "Não é uma interface IPv4 ou IPv6", 
        "value is not a valid IPv4 or IPv6 network": "Não é uma rede IPv4 or IPv6", 
        "value is not a valid IPv4 address": "Não é um endereço IPv4 ", 
        "value is not a valid IPv6 address": "Não é um endereço IPv6 ", 
        "value is not a valid IPv4 network": "Não é uma rede IPv4", 
        "value is not a valid IPv6 network": "Não é um rede IPv6", 
        "value is not a valid IPv4 interface": "Não é um interface IPv4", 
        "value is not a valid IPv6 interface": "Não é um interface IPv6", 
        "value is not a valid color: {}": "Não é uma cor válida: {}", 
        "value is not a valid boolean": "O campo precisa ser verdadeiro ou falso", 
        "card number is not all digits": "Está faltando números do cartão de crédito", 
        "card number is not luhn valid": "Cartão de crédito inválido (não é válido)", 
        "Length for a {}": "Tamanho inválido para {} ", 
        "could not parse value and unit from byte string": "Não foi possível converter os dados de binário para texto", 
        "could not interpret byte unit: {}": "Não conseguimos interpretar: {}", 
        "Discriminator {} is missing in value": "O valor: {} precisa estar presente", 
        "No match for discriminator ({})": "Não contém o valor: ({})"
    }
}

==> pydantic_errors_messages_translations-1.1.1.tar.gz: pydantic_errors_messages_translations-1.1.1/pydantic_errors_messages_translations/translations.py <==
from typing import Dict


pydantic_msg_template_translations: Dict[str, Dict] = {
    'pt_BR': {
        "field required": "Campo Obrigatório", 
        "extra fields not permitted": "Campos adicinais não são permitidos", 
        "none is not an allowed value": "Nulo não é um valor permitido", 
        "value is not none": "Valor não é nulo", 
        "value is not None": "Valor não é nulo", 
        "value could not be parsed to a boolean": "Valor não poderia ser convertido para um booleano",
        "byte type expected": "Tipo binário esperado era", 
        "value is not a valid dict": "Valor não é um dicionário válido", 
        "value is not a valid email address": "nao é um endereço de e-mail válido", 
        "invalid or missing URL scheme": "URL inválido ou faltando", 
        "URL scheme not permitted": "Formato de URL não permitido", 
        "userinfo required in URL but missing": "userinfo required in URL but missing", 
        "URL host invalid": "Dominio inválido", 
        "URL host invalid, top level domain required": "É necessário que a URL tenha um Top Level Domain", 
        "URL port invalid, port cannot exceed 65535": "URL porta inválida, porta não pode exceder 65535", 
        "URL invalid, extra characters found after valid URL: {}": "URL inválida, caracteres extras foram encontrados após a URL: {}", 
        "{} is not a valid Enum instance": "{} Não é uma instância válida de Enum", 
        "{} is not a valid IntEnum instance": "{} não é uma instância válida de IntEnum", 
        "value is not a valid integer": "Não é um número válido", 
        "value is not a valid float": "Não é um número válido", 
        "value is not a valid path": "Não um diretorio válido", 
        "file or directory at path '{}' does not exist":  "Arquivo ou diretório neste caminho '{}' não existe", 
        "path '{}' does not point to a file": "O caminho '{}' não aponta para um arquivo", 
        "path '{}' does not point to a directory": "O caminho '{}' não aponta para um diretório", 
        "ensure this value contains valid import path or valid callable: {}": "O valor não contém uma importação para um arquivo ou função válida: {}", 
        "value is not a valid sequence": "Valor não é uma sequência válida", 
        "value is not a valid list": "Valor não é uma lista válida", 
        "value is not a valid set": "Valor não é um conjunto válido", 
        "value is not a valid frozenset": "Valor não é um frozenset válido", 
        "value is not a valid tuple": "Valor não é uma tupla válida", 
        "wrong tuple length {}": "wrong tuple length {}", 
        "ensure this value has at least {} items": "Este campo precisa ter menos que {} itens", 
        "ensure this value has at most {} items": "Este campo precisa ter mais que {} items", 
        "the list has duplicated items": "Contém itens duplicados", 
        "ensure this value has at least {} characters": "Este campo precisa ter menos que {} caracteres", 
        "ensure this value has at most {} characters": "Este campo precisa ter mais que {} caracteres", 
        "str type expected": "O valor precisa ser um texto", 
        "string does not match regex '{}'": "string does not match regex '{}'", 
        "ensure this value is greater than {}": "O valor deve ser maior que {}", 
        "ensure this value is greater than or equal to {}": "ensure this value is greater than or equal to {}", 
        "ensure this value is less than {}": "ensure this value is less than {}", 
        "ensure this value is less than or equal to {}": "ensure this value is less than or equal to {}", 
        "ensure this value is a multiple of {}": "ensure this value is a multiple of {}", 
        "value is not a valid decimal": "Não é um número decimal válido", 
        "ensure that there are no more than {} digits in total": "Não deve ter menos que {} dígitos no total", 
        "ensure that there are no more than {} decimal places": "Não deve ter mais que {} casas decimais", 
        "ensure that there are no more than {} digits before the decimal point": "Deve ter mais que {} digitos antes do ponto", 
        "invalid datetime format": "Formato de data e hora inválido", 
        "invalid date format": "Formato de data inválido", 
        "date is not in the past": "A Data não pode ser menor que agora", 
        "date is not in the future": "A Data não pode ser maior que agora", 
        "invalid time format": "Formato de tempo inválido", 
        "invalid duration format": "iDUração de tempo inválida", 
        "value is not a valid hashable": "Não é um hash válido", 
        "value is not a valid uuid": "Não é um uuid válido", 
        "uuid version {} expected": "uuid version {} expected", 
        "instance of {} expected": "Uma instância de {} era esperada", 
        "a class is expected": "Uma classe era esperada", 
        "subclass of {} expected": "Uma subclasse de {} era esperada", 
        "Invalid JSON": "JSON inválido", 
        "JSON object must be str, bytes or bytearray": "O JSON enviado precisa ser texto, binário ou uma lista de arquivos binários", 
        "Invalid regular expression": "Expressão regular inválida", 
        "instance of {}, tuple or dict expected": "Uma instância de {}, tupla ou dicionário era esperada", 
        "{} is not callable": "{} não é uma função", 
        "value is not a valid IPv4 or IPv6 address": "Não é um endereço IPv4 or IPv6", 
        "value is not a valid IPv4 or IPv6 interface": "Não é uma interface IPv4 ou IPv6", 
        "value is not a valid IPv4 or IPv6 network": "Não é uma rede IPv4 or IPv6", 
        "value is not a valid IPv4 address": "Não é um endereço IPv4 ", 
        "value is not a valid IPv6 address": "Não é um endereço IPv6 ", 
        "value is not a valid IPv4 network": "Não é uma rede IPv4", 
        "value is not a valid IPv6 network": "Não é um rede IPv6", 
        "value is not a valid IPv4 interface": "Não é um interface IPv4", 
        "value is not a valid IPv6 interface": "Não é um interface IPv6", 
        "value is not a valid color: {}": "Não é uma cor válida: {}", 
        "value is not a valid boolean": "O campo precisa ser verdadeiro ou falso", 
        "card number is not all digits": "Está faltando números do cartão de crédito", 
        "card number is not luhn valid": "Cartão de crédito inválido (não é válido)", 
        "Length for a {}": "Tamanho inválido para {} ", 
        "could not parse value and unit from byte string": "Não foi possível converter os dados de binário para texto", 
        "could not interpret byte unit: {}": "Não conseguimos interpretar: {}", 
        "Discriminator {} is missing in value": "O valor: {} precisa estar presente", 
        "No match for discriminator ({})": "Não contém o valor: ({})"
    }
}
